/*
 * © 2009 David ‘Bombe’ Roden
 */
package net.pterodactylus.arachne.parser;

import java.io.IOException;
import java.io.InputStream;

/**
 * Interface for a parser. A parser understands the format it should parse and
 * can generate events based on the parsed content.
 *
 * @see ParserListener
 * @author David ‘Bombe’ Roden <bombe@pterodactylus.net>
 */
public interface Parser {

	/**
	 * Parses the given input stream and sends events to the given listener.
	 *
	 * @param parserListener
	 *            The listener to send events to
	 * @param inputStream
	 *            The input stream to parse
	 * @param charset
	 *            The charset to use for parsing, or <code>null</code> if the
	 *            charset is unknown or the file is “binary” file, i.e. not
	 *            characters are read from it but bytes (e.g. image files)
	 * @throws IOException
	 *             if an I/O error occurs
	 */
	public void parse(ParserListener parserListener, InputStream inputStream, String charset) throws IOException;

}
